.. _delu:

delu
====

.. currentmodule:: delu

.. automodule:: delu

.. rubric:: Data

.. autosummary::
   :nosignatures:
   :toctree: api
   :template: class.rst

   Stream

.. rubric:: Monitoring

.. autosummary::
   :nosignatures:
   :toctree: api
   :template: class.rst

   ProgressTracker
   Timer

.. rubric:: Tensor operations

.. autosummary::
   :nosignatures:
   :toctree: api

   collate
   concat
   iter_batches

.. rubric:: Utilities

.. autosummary::
   :nosignatures:
   :toctree: api

   improve_reproducibility

.. autosummary::
   :nosignatures:
   :toctree: api
   :template: class_just_autoclass.rst

   evaluation

.. rubric:: Submodules

See the sidebar on the left.
